@@ -5,9 +5,10 @@
 #' @inheritParams ggbetweenstats
 #' @param ... Currently ignored.
 #'
-#' @importFrom groupedstats grouped_summary
-#' @importFrom dplyr select group_by vars contains mutate mutate_at group_nest
-#' @importFrom rlang !! enquo ensym
+#' @importFrom parameters describe_distribution
+#' @importFrom broomExtra easystats_to_tidy_names
+#' @importFrom dplyr select group_by matches mutate mutate_at group_nest group_modify
+#' @importFrom rlang !! enquo ensym :=
 #' @importFrom purrr map
 #' @importFrom tidyr drop_na unnest
 #'
@@ -30,35 +31,19 @@ mean_labeller <- function(data,
                           ...) {
 
   # creating the dataframe
-  data %<>%
+  data %>%
     dplyr::select(.data = ., {{ x }}, {{ y }}) %>%
-    tidyr::drop_na(data = .) %>%
+    tidyr::drop_na(.) %>%
     dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }}))) %>%
-    as_tibble(x = .)
-
-  # computing mean and confidence interval for mean
-  mean_dat <-
-    groupedstats::grouped_summary(
-      data = data,
-      grouping.vars = {{ x }},
-      measures = {{ y }}
-    ) %>% # introduce non-syntactic names to allow for `mean` pattern names
-    dplyr::rename_at(
-      .tbl = .,
-      .vars = dplyr::vars(dplyr::matches("mean|^n$")),
-      .funs = ~ paste(., "...summary", sep = "")
+    as_tibble(.) %>%
+    dplyr::group_by(.data = ., {{ x }}) %>%
+    dplyr::group_modify(
+      .f = ~ broomExtra::easystats_to_tidy_names(
+        parameters::describe_distribution(x = ., centrality = "mean", ci = 0.95)
+      )
     ) %>%
-    dplyr::mutate(.data = ., {{ y }} := `mean...summary`) %>%
-    dplyr::select(.data = ., {{ x }}, {{ y }}, dplyr::contains("...")) %>%
-    dplyr::mutate_at(
-      .tbl = .,
-      .vars = dplyr::vars(dplyr::matches("^mean\\.\\.\\.|^mean\\.conf")),
-      .funs = ~ specify_decimal_p(x = ., k = k)
-    ) %>%
-    dplyr::group_nest(.tbl = ., {{ x }})
-
-  # adding confidence intervals to the label for mean
-  mean_dat %<>%
+    dplyr::ungroup(.) %>%
+    dplyr::group_nest(.tbl = ., {{ x }}) %>%
     dplyr::mutate(
       .data = .,
       label = data %>% {
@@ -67,13 +52,13 @@ mean_labeller <- function(data,
             .x = .,
             .f = ~ paste(
               "list(~italic(widehat(mu))==",
-              .$`mean...summary`,
+              specify_decimal_p(.$mean, k),
               ",",
               "CI[95*'%']",
               "*'['*",
-              .$`mean.conf.low...summary`,
+              specify_decimal_p(.$conf.low, k),
               ",",
-              .$`mean.conf.high...summary`,
+              specify_decimal_p(.$conf.high, k),
               "*']')",
               sep = ""
             )
@@ -81,23 +66,23 @@ mean_labeller <- function(data,
         } else {
           purrr::map(
             .x = .,
-            .f = ~ paste("list(~italic(widehat(mu))==", .$`mean...summary`, ")", sep = " ")
+            .f = ~ paste(
+              "list(~italic(widehat(mu))==",
+              specify_decimal_p(.$mean, k),
+              ")",
+              sep = ""
+            )
           )
         }
       }
-    )
-
-  # adding sample size labels and arranging by original factor levels
-  mean_dat %<>%
+    ) %>%
     tidyr::unnest(data = ., cols = c(data, label)) %>%
     dplyr::mutate(
       .data = .,
-      n_label = paste0({{ x }}, "\n(n = ", `n...summary`, ")", sep = "")
+      n_label = paste0({{ x }}, "\n(n = ", n, ")", sep = "")
     ) %>%
-    dplyr::arrange(.data = ., {{ x }})
-
-  # return the dataframe with mean information
-  return(dplyr::select(mean_dat, -dplyr::contains("...")))
+    dplyr::arrange(.data = ., {{ x }}) %>%
+    dplyr::select(.data = ., {{ x }}, !!as.character(rlang::ensym(y)) := mean, dplyr::matches("label"))
 }
 
 
@@ -223,7 +208,6 @@ ggsignif_adder <- function(plot,
                            data,
                            x,
                            y,
-                           pairwise.annotation = "p.value",
                            pairwise.display = "significant",
                            ...) {
   # creating a column for group combinations
@@ -244,24 +228,9 @@ ggsignif_adder <- function(plot,
     }
 
     # proceed only if there are any significant comparisons to display
-    if (dim(df_pairwise)[[1]] != 0L) {
-      # deciding what needs to be displayed
-      if (pairwise.annotation %in% c("p", "p-value", "p.value")) {
-        # if p-values are to be displayed
-        parse <- TRUE
-      } else {
-        # otherwise just show the asterisks
-        df_pairwise %<>%
-          dplyr::select(.data = ., -label) %>%
-          dplyr::rename(.data = ., label = significance)
-
-        parse <- FALSE
-      }
-    } else {
+    if (dim(df_pairwise)[[1]] == 0L) {
       return(plot)
     }
-  } else {
-    parse <- TRUE
   }
 
   # arrange the dataframe so that annotations are properly aligned
@@ -282,7 +251,7 @@ ggsignif_adder <- function(plot,
       annotations = df_pairwise$label,
       test = NULL,
       na.rm = TRUE,
-      parse = parse
+      parse = TRUE
     )
 }
 
@@ -332,7 +301,6 @@ aesthetic_addon <- function(plot,
                             ggstatsplot.layer = TRUE,
                             package = "RColorBrewer",
                             palette = "Dark2",
-                            direction = 1,
                             ggplot.component = NULL,
                             ...) {
 
@@ -358,14 +326,8 @@ aesthetic_addon <- function(plot,
       ggstatsplot.layer = ggstatsplot.layer
     ) +
     ggplot2::theme(legend.position = "none") +
-    paletteer::scale_color_paletteer_d(
-      palette = paste0(package, "::", palette),
-      direction = direction
-    ) +
-    paletteer::scale_fill_paletteer_d(
-      palette = paste0(package, "::", palette),
-      direction = direction
-    )
+    paletteer::scale_color_paletteer_d(paste0(package, "::", palette)) +
+    paletteer::scale_fill_paletteer_d(paste0(package, "::", palette))
 
   # ---------------- adding ggplot component ---------------------------------
 
